public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH]O20.3int
@ 2003-09-16  1:00 Con Kolivas
  0 siblings, 0 replies; only message in thread
From: Con Kolivas @ 2003-09-16  1:00 UTC (permalink / raw)
  To: linux kernel mailing list; +Cc: Andrew Morton

[-- Attachment #1: Type: text/plain, Size: 111 bytes --]

Yep I really hate doing this, sorry. This is what I was supposed to do in 
O20.2int.

applies to O20.2int

Con

[-- Attachment #2: patch-O20.2-O20.3int --]
[-- Type: text/x-diff, Size: 703 bytes --]

--- linux-2.6.0-test5-mm2-O20.2/kernel/sched.c	2003-09-16 09:27:57.000000000 +1000
+++ linux-2.6.0-test5-mm2-O20.3/kernel/sched.c	2003-09-16 10:50:49.000000000 +1000
@@ -1426,11 +1426,11 @@ void scheduler_tick(int user_ticks, int 
 		 * equal priority.
 		 *
 		 * This only applies to tasks in the interactive
 		 * delta range with at least MIN_TIMESLICE to requeue.
 		 */
 		if (TASK_INTERACTIVE(p) && !((task_timeslice(p) -
 			p->time_slice) % TIMESLICE_GRANULARITY(p)) &&
-			(p->time_slice >= MIN_TIMESLICE) &&
+			(p->time_slice >= TIMESLICE_GRANULARITY(p)) &&
 			(p->array == rq->active)) {
 
 			dequeue_task(p, rq->active);

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2003-09-16  0:52 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -1426,11 +1426,11 @@ void scheduler_tick(int user_ticks, int 
 		 *
 		 * This only applies to tasks in the interactive
-		 * delta range with at least MIN_TIMESLICE to requeue.
+		 * delta range with at least TIMESLICE_GRANULARITY to requeue.
 		 */
 		if (TASK_INTERACTIVE(p) && !((task_timeslice(p) -
2003-09-16  1:00 [PATCH]O20.3int Con Kolivas

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox